<?php

namespace FiloBlu\ProductUrlTools\Helper;

use Symfony\Component\Console\Helper\ProgressBar;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class Progress
 * @package FiloBlu\ProductUrlTools\Helper
 */
class Progress
{
    /**
     * @var ProgressBar[]
     */
    protected $progressBar = [];
    /**
     * @var OutputInterface
     */
    protected $output;
    /**
     * @var bool
     */
    protected $upLineString = null;

    /**
     * @param OutputInterface $output
     */
    public function bind(OutputInterface $output)
    {
        $this->output = $output;
        ProgressBar::setFormatDefinition('custom', ' %message% %current%/%max% [%bar%] %percent:3s%% %elapsed:6s% ');
    }

    /**
     * @param $id
     * @param int $max Maximum steps (0 if unknown)
     */
    public function add($id, $max = 0)
    {
        $this->progressBar[$id] = new ProgressBar($this->output, $max);
        $this->progressBar[$id]->setFormat('custom');
        $this->progressBar[$id]->setOverwrite(false);
        $this->progressBar[$id]->start();

        $this->output->writeln('');
    }

    /**
     * @param $id
     * @param int $step Number of steps to advance
     */
    public function advance($id, $step = 1)
    {
        if ($this->upLineString === null) {
            $this->upLineString = str_repeat("\033[1A", count($this->progressBar));
        }
        $this->output->write($this->upLineString);

        foreach ($this->progressBar as $k => $bar) {
            $this->progressBar[$id]->setMessage("$id");
            if ($k == $id) {
                $this->progressBar[$id]->advance($step);
            }
            $this->output->writeln('');
        }
    }

    /**
     * @param $id
     */
    public function finish($id)
    {
        $this->progressBar[$id]->finish();
    }
}